@@ -279,6 +279,26 @@ class EscriptoriumConnector:
         )
         return r
 
+    def get_document_part_transcriptions(self, doc_pk: int, part_pk: int):
+        get_url = f"{self.api_url}documents/{doc_pk}/parts/{part_pk}/transcriptions/"
+        r = self.__get_url(get_url)
+        transcriptions_info = r.json()
+        transcriptions = transcriptions_info["results"]
+        while transcriptions_info["next"] is not None:
+            r = self.__get_url(transcriptions_info["next"])
+            transcriptions_info = r.json()
+            transcriptions = transcriptions + transcriptions_info["results"]
+        return transcriptions
+
+    def create_document_part_transcription(
+        self, doc_pk: int, part_pk: int, transcription: object
+    ):
+        r = self.__post_url(
+            f"{self.api_url}documents/{doc_pk}/parts/{part_pk}/transcriptions/",
+            transcription,
+        )
+        return r
+
     def get_document_images(self, document_pk: int):
         r = self.__get_url(f"{self.api_url}documents/{document_pk}/parts/")
         image_info = r.json()
